@@ -301,8 +301,7 @@ class IgSession(Session):
         sentiment_url = self._master_url + f"clientsentiment/{market_id}"
 
         r = self._request_retry_allowance(requests.get, url=sentiment_url, headers=self._headers)
-        if r.status_code != 200:
-            raise LoginError(f"Failed to login: {r.text}")
+        assert r.status_code == 200, (r.status_code, r.text)
 
         if (
             r.json()["longPositionPercentage"]
@@ -322,7 +321,7 @@ class IgSession(Session):
             "password": password,
             "encryptedPassword": None,
         }
-        r = requests.post(url=login_url, headers=self._headers, json=body)
+        r = self._request_retry_allowance(requests.post, url=login_url, headers=self._headers, json=body)
         if r.status_code != 200:
             raise LoginError(f"Failed to login: {r.text}")
         self._headers["cst"] = r.headers["cst"]
